@@ -46,10 +46,10 @@
 #include <gtk/gtk.h>
 
 #include <canberra-gtk.h>
+#include <libnotify/notify.h>
 
 #include "brasero-burn-dialog.h"
 
-#include "brasero-tray.h"
 #include "brasero-session-cfg.h"
 #include "brasero-session-helper.h"
 
@@ -75,15 +75,6 @@ static void
 brasero_burn_dialog_cancel_clicked_cb (GtkWidget *button,
 				       BraseroBurnDialog *dialog);
 
-static void
-brasero_burn_dialog_tray_cancel_cb (BraseroTrayIcon *tray,
-				    BraseroBurnDialog *dialog);
-
-static void
-brasero_burn_dialog_tray_show_dialog_cb (BraseroTrayIcon *tray,
-					 gboolean show,
-					 GtkWidget *dialog);
-
 typedef struct BraseroBurnDialogPrivate BraseroBurnDialogPrivate;
 struct BraseroBurnDialogPrivate {
 	BraseroBurn *burn;
@@ -97,7 +88,6 @@ struct BraseroBurnDialogPrivate {
 	GtkWidget *header;
 	GtkWidget *cancel;
 	GtkWidget *image;
-	BraseroTrayIcon *tray;
 
 	/* for our final statistics */
 	GTimer *total_time;
@@ -146,6 +136,49 @@ brasero_burn_dialog_update_media (BraseroBurnDialog *dialog)
 	priv->media = media;
 }
 
+static void
+brasero_burn_dialog_notify_daemon_close (NotifyNotification *notification,
+                                         BraseroBurnDialog *dialog)
+{
+	g_object_unref (notification);
+}
+
+static gboolean
+brasero_burn_dialog_notify_daemon (BraseroBurnDialog *dialog,
+                                   const char *message)
+{
+        NotifyNotification *notification;
+	GError *error = NULL;
+        gboolean result;
+
+	if (!notify_is_initted ()) {
+		notify_init (_("Brasero notification"));
+	}
+
+        notification = notify_notification_new (message,
+                                                NULL,
+                                                GTK_STOCK_CDROM);
+
+	if (!notification)
+                return FALSE;
+
+	g_signal_connect (notification,
+                          "closed",
+                          G_CALLBACK (brasero_burn_dialog_notify_daemon_close),
+                          dialog);
+
+	notify_notification_set_timeout (notification, 10000);
+	notify_notification_set_urgency (notification, NOTIFY_URGENCY_NORMAL);
+
+	result = notify_notification_show (notification, &error);
+	if (error) {
+		g_warning ("Error showing notification");
+		g_error_free (error);
+	}
+
+	return result;
+}
+
 static GtkWidget *
 brasero_burn_dialog_create_message (BraseroBurnDialog *dialog,
                                     GtkMessageType type,
@@ -984,13 +1017,12 @@ brasero_burn_dialog_eject_failure_cb (BraseroBurn *burn,
 	gchar *name;
 	gchar *string;
 	gint removal_id;
-	GtkWindow *window;
 	GtkWidget *message;
 	gboolean hide = FALSE;
 	BraseroBurnDialogPrivate *priv;
 
 	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
-
+	
 	if (!gtk_widget_get_visible (GTK_WIDGET (dialog))) {
 		gtk_widget_show (GTK_WIDGET (dialog));
 		hide = TRUE;
@@ -998,8 +1030,6 @@ brasero_burn_dialog_eject_failure_cb (BraseroBurn *burn,
 
 	g_timer_stop (priv->total_time);
 
-	window = GTK_WINDOW (dialog);
-
 	name = brasero_drive_get_display_name (drive);
 	/* Translators: %s is the name of a drive */
 	string = g_strdup_printf (_("Please eject the disc from \"%s\" manually."), name);
@@ -1119,16 +1149,10 @@ brasero_burn_dialog_update_title_writing_progress (BraseroBurnDialog *dialog,
 						   BraseroMedia media,
 						   guint percent)
 {
-	BraseroBurnDialogPrivate *priv;
-	BraseroBurnFlag flags;
 	gchar *title = NULL;
 	gchar *icon_name;
 	guint remains;
 
-	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
-
-	flags = brasero_burn_session_get_flags (priv->session);
-
 	/* This is used only when actually writing to a disc */
 	if (media == BRASERO_MEDIUM_FILE)
 		title = brasero_burn_dialog_create_dialog_title_for_action (dialog,
@@ -1220,10 +1244,6 @@ brasero_burn_dialog_progress_changed_real (BraseroBurnDialog *dialog,
 					  mb_written,
 					  rate);
 
-	brasero_tray_icon_set_progress (BRASERO_TRAYICON (priv->tray),
-					task_progress,
-					remaining);
-
 	if (rate > 0 && priv->is_writing)
 		priv->rates = g_slist_prepend (priv->rates, GINT_TO_POINTER ((gint) rate));
 }
@@ -1273,9 +1293,6 @@ brasero_burn_dialog_action_changed_real (BraseroBurnDialog *dialog,
 	brasero_burn_progress_set_action (BRASERO_BURN_PROGRESS (priv->progress),
 					  action,
 					  string);
-	brasero_tray_icon_set_action (BRASERO_TRAYICON (priv->tray),
-				      action,
-				      string);
 }
 
 static void
@@ -1413,7 +1430,7 @@ brasero_burn_dialog_activity_start (BraseroBurnDialog *dialog)
 	if (window) {
 		cursor = gdk_cursor_new (GDK_WATCH);
 		gdk_window_set_cursor (window, cursor);
-		gdk_cursor_unref (cursor);
+		g_object_unref (cursor);
 	}
 
 	gtk_button_set_use_stock (GTK_BUTTON (priv->cancel), TRUE);
@@ -1501,7 +1518,7 @@ brasero_burn_dialog_install_missing_cb (BraseroBurn *burn,
 
 	/* Get the xid */
 	window = gtk_widget_get_window (user_data);
-	xid = gdk_x11_drawable_get_xid (GDK_DRAWABLE (window));
+	xid = gdk_x11_window_get_xid (window);
 
 	package = brasero_pk_new ();
 	cancel = g_cancellable_new ();
@@ -1617,18 +1634,10 @@ brasero_burn_dialog_setup_session (BraseroBurnDialog *dialog,
 					  -1,
 					  -1);
 
-	brasero_tray_icon_set_progress (BRASERO_TRAYICON (priv->tray),
-					0.0,
-					-1);
-
 	brasero_burn_progress_set_action (BRASERO_BURN_PROGRESS (priv->progress),
 					  BRASERO_BURN_ACTION_NONE,
 					  NULL);
 
-	brasero_tray_icon_set_action (BRASERO_TRAYICON (priv->tray),
-				      BRASERO_BURN_ACTION_NONE,
-				      NULL);
-
 	g_timer_continue (priv->total_time);
 
 	return BRASERO_BURN_OK;
@@ -1747,6 +1756,8 @@ brasero_burn_dialog_notify_error (BraseroBurnDialog *dialog,
 			       GTK_STOCK_CLOSE,
 			       GTK_RESPONSE_CLOSE);
 
+	brasero_burn_dialog_notify_daemon (dialog, _("Error while burning."));
+
 	response = gtk_dialog_run (GTK_DIALOG (message));
 	while (response == GTK_RESPONSE_OK) {
 		brasero_burn_dialog_save_log (dialog);
@@ -1777,7 +1788,6 @@ brasero_burn_dialog_get_success_message (BraseroBurnDialog *dialog)
 			else
 				return g_strdup (_("Audio CD successfully burned"));
 		}
-
 		return g_strdup (_("Image successfully created"));
 	}
 	else if (brasero_track_type_get_has_medium (&priv->input)) {
@@ -1809,7 +1819,6 @@ brasero_burn_dialog_get_success_message (BraseroBurnDialog *dialog)
 			else
 				return g_strdup (_("Data CD successfully burned"));
 		}
-
 		return g_strdup (_("Image successfully created"));
 	}
 
@@ -1889,6 +1898,8 @@ brasero_burn_dialog_notify_copy_finished (BraseroBurnDialog *dialog,
 	                        CA_PROP_EVENT_ID, "complete-media-burn",
 	                        CA_PROP_EVENT_DESCRIPTION, main_message,
 	                        NULL);
+
+	brasero_burn_dialog_notify_daemon (dialog, main_message);
 	g_free (main_message);
 
 	response = gtk_dialog_run (GTK_DIALOG (message));
@@ -1967,6 +1978,7 @@ brasero_burn_dialog_notify_success (BraseroBurnDialog *dialog)
 			       CA_PROP_EVENT_DESCRIPTION, primary,
 			       NULL);
 
+	brasero_burn_dialog_notify_daemon (dialog, primary);
 	g_free (primary);
 
 	res = brasero_burn_dialog_success_run (dialog);
@@ -2496,18 +2508,6 @@ brasero_burn_dialog_cancel (BraseroBurnDialog *dialog,
 	return TRUE;
 }
 
-static gboolean
-brasero_burn_dialog_delete (GtkWidget *widget, 
-			    GdkEventAny *event)
-{
-	BraseroBurnDialogPrivate *priv;
-
-	priv = BRASERO_BURN_DIALOG_PRIVATE (widget);
-
-	brasero_tray_icon_set_show_dialog (BRASERO_TRAYICON (priv->tray), FALSE);
- 	return TRUE;
-}
-
 static void
 brasero_burn_dialog_cancel_clicked_cb (GtkWidget *button,
 				       BraseroBurnDialog *dialog)
@@ -2516,39 +2516,6 @@ brasero_burn_dialog_cancel_clicked_cb (GtkWidget *button,
 	brasero_burn_dialog_cancel (dialog, FALSE);
 }
 
-static void
-brasero_burn_dialog_tray_cancel_cb (BraseroTrayIcon *tray,
-				    BraseroBurnDialog *dialog)
-{
-	brasero_burn_dialog_cancel (dialog, FALSE);
-}
-
-static void
-brasero_burn_dialog_tray_show_dialog_cb (BraseroTrayIcon *tray,
-					 gboolean show,
-					 GtkWidget *dialog)
-{
-	BraseroBurnDialogPrivate *priv;
-
-	priv = BRASERO_BURN_DIALOG_PRIVATE (dialog);
-
-	/* we prevent to show the burn dialog once the success dialog has been 
-	 * shown to avoid the following strange behavior:
-	 * Steps:
-	 * - start burning
-	 * - move to another workspace (ie, virtual desktop)
-	 * - when the burning finishes, double-click the notification icon
-	 * - you'll be unable to dismiss the dialogues normally and their behaviour will
-	 *   be generally strange */
-	if (!priv->burn)
-		return;
-
-	if (show)
-		gtk_widget_show (dialog);
-	else
-		gtk_widget_hide (dialog);
-}
-
 static void
 brasero_burn_dialog_init (BraseroBurnDialog * obj)
 {
@@ -2561,16 +2528,6 @@ brasero_burn_dialog_init (BraseroBurnDialog * obj)
 
 	gtk_window_set_default_size (GTK_WINDOW (obj), 500, 0);
 
-	priv->tray = brasero_tray_icon_new ();
-	g_signal_connect (priv->tray,
-			  "cancel",
-			  G_CALLBACK (brasero_burn_dialog_tray_cancel_cb),
-			  obj);
-	g_signal_connect (priv->tray,
-			  "show-dialog",
-			  G_CALLBACK (brasero_burn_dialog_tray_show_dialog_cb),
-			  obj);
-
 	alignment = gtk_alignment_new (0.5, 0.5, 1.0, 1.0);
 	gtk_widget_show (alignment);
 	gtk_alignment_set_padding (GTK_ALIGNMENT (alignment), 6, 8, 6, 6);
@@ -2613,22 +2570,6 @@ brasero_burn_dialog_init (BraseroBurnDialog * obj)
 					      GTK_RESPONSE_CANCEL);
 }
 
-static void
-brasero_burn_dialog_destroy (GtkObject * object)
-{
-	BraseroBurnDialogPrivate *priv;
-
-	priv = BRASERO_BURN_DIALOG_PRIVATE (object);
-
-	if (priv->burn) {
-		g_object_unref (priv->burn);
-		priv->burn = NULL;
-	}
-
-	if (GTK_OBJECT_CLASS (brasero_burn_dialog_parent_class)->destroy)
-		GTK_OBJECT_CLASS (brasero_burn_dialog_parent_class)->destroy (object);
-}
-
 static void
 brasero_burn_dialog_finalize (GObject * object)
 {
@@ -2662,11 +2603,6 @@ brasero_burn_dialog_finalize (GObject * object)
 		priv->burn = NULL;
 	}
 
-	if (priv->tray) {
-		g_object_unref (priv->tray);
-		priv->tray = NULL;
-	}
-
 	if (priv->session) {
 		g_object_unref (priv->session);
 		priv->session = NULL;
@@ -2689,14 +2625,10 @@ static void
 brasero_burn_dialog_class_init (BraseroBurnDialogClass * klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkObjectClass *gtk_object_class = GTK_OBJECT_CLASS (klass);
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 
 	g_type_class_add_private (klass, sizeof (BraseroBurnDialogPrivate));
 
 	object_class->finalize = brasero_burn_dialog_finalize;
-	gtk_object_class->destroy = brasero_burn_dialog_destroy;
-	widget_class->delete_event = brasero_burn_dialog_delete;
 }
 
 /**
